pub struct Selector {
pub offers: Option<Vec<Offer>>,
pub include_properties: Option<Vec<ResourceProperty>>,
pub exclude_properties: Option<Vec<ResourceProperty>>,
/* private fields */
}Expand description
Selector used to match resources as a dependency for nodes.
Fields
offers: Option<Vec<Offer>>The resource must contain these offers.
include_properties: Option<Vec<ResourceProperty>>The resource must contain these properties. The property keys must be unique for the Selector to be considered valid.
exclude_properties: Option<Vec<ResourceProperty>>The resource must not contain these properties.